@@ -15,7 +15,8 @@ class TLFBData(CalculatorData):
         """
         Create the instance object for the TLFB data
 
-        :param filepath: Union[str, path], the file path to the TLFB data
+        :param filepath: Union[str, path, DataFrame], the file path to the TLFB data or the created DataFrame
+
 
         :param abst_cutoff: Union[float, int], the cutoff equal to or below which is abstinent
 
@@ -23,7 +24,7 @@ class TLFBData(CalculatorData):
             the default option "all" means that all subjects in the dataset will be used
 
         """
-        df = super().read_data_from_path(filepath)
+        df = filepath if isinstance(filepath, pd.DataFrame) else super().read_data_from_path(filepath)
         self.data = self._validated_data(df)
         if included_subjects and included_subjects != "all":
             self.data = self.data.loc[self.data["id"].isin(included_subjects), :].reset_index(drop=True)
@@ -56,7 +57,7 @@ class TLFBData(CalculatorData):
         """
         tlfb_summary_series = self._get_tlfb_sample_summary(min_amount_cutoff, max_amount_cutoff)
         tlfb_subject_summary = self._get_tlfb_subject_summary(min_amount_cutoff, max_amount_cutoff)
-        sns.distplot(self.data['amount'])
+        sns.displot(self.data['amount'])
         plt.show()
         return tlfb_summary_series, tlfb_subject_summary
 
@@ -187,11 +188,11 @@ class TLFBData(CalculatorData):
         :return: Summary of the recoding
         """
         recode_summary = dict()
-        outlier_count_low = pd.Series(self.data['amount'] < floor_amount).sum()
+        outlier_count_low = int(pd.Series(self.data['amount'] < floor_amount).sum())
         recode_summary[f'Number of outliers (< {floor_amount})'] = outlier_count_low
         self.data['amount'] = self.data['amount'].map(
             lambda x: np.nan if drop_outliers and x < floor_amount else max(x, floor_amount))
-        outlier_count_high = pd.Series(self.data['amount'] > ceil_amount).sum()
+        outlier_count_high = int(pd.Series(self.data['amount'] > ceil_amount).sum())
         recode_summary[f'Number of outliers (> {ceil_amount})'] = outlier_count_high
         self.data['amount'] = self.data['amount'].map(
             lambda x: np.nan if drop_outliers and x > ceil_amount else min(x, ceil_amount))
@@ -243,7 +244,7 @@ class TLFBData(CalculatorData):
         """
         if impute is None or str(impute).lower() == "none":
             return
-        if not (impute in ("uniform", "linear") or impute.isnumeric()):
+        if not (impute in ("uniform", "linear") or str(impute).isnumeric()):
             raise InputArgumentError("The imputation mode can only be None, 'uniform', 'linear', "
                                      "or a numeric value.")
         if 'imputation_code' in self.data.columns:
@@ -263,8 +264,12 @@ class TLFBData(CalculatorData):
             to_concat.append(last_records)
 
         if biochemical_data is not None:
-            _biochemical_data = \
-                biochemical_data.data.drop(columns="imputation_code").rename(columns={"amount": "bio_amount"})
+            if "imputation_code" in biochemical_data.data.columns:
+                _biochemical_data = \
+                    biochemical_data.data.drop(columns="imputation_code").rename(columns={"amount": "bio_amount"})
+            else:
+                _biochemical_data = \
+                    biochemical_data.data.rename(columns={"amount": "bio_amount"})
             _merged = self.data.merge(_biochemical_data, how="left", on=["id", "date"])
             bio_amount = (self.abst_cutoff + 1) if overridden_amount == 'infer' else float(overridden_amount)
 
